Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(668)

Unified Diff: third_party/tcmalloc/chromium/src/windows/mini_disassembler_types.h

Issue 9666033: Experiment for updating the tcmalloc chromium branch to r144 (gperftools 2.0). (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Created 8 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: third_party/tcmalloc/chromium/src/windows/mini_disassembler_types.h
diff --git a/third_party/tcmalloc/chromium/src/windows/mini_disassembler_types.h b/third_party/tcmalloc/chromium/src/windows/mini_disassembler_types.h
index 7f8e99724b4c2361f5a8e9d4103ac13463f840fa..83dee8ba920f68e0361d22050c2c0aba8a3a5a72 100644
--- a/third_party/tcmalloc/chromium/src/windows/mini_disassembler_types.h
+++ b/third_party/tcmalloc/chromium/src/windows/mini_disassembler_types.h
@@ -143,6 +143,16 @@ enum OperandType {
OT_ADDRESS_MODE_M = 0x80000000
};
+// Flag that indicates if an immediate operand is 64-bits.
+//
+// The Intel 64 and IA-32 Architecture Software Developer's Manual currently
+// defines MOV as the only instruction supporting a 64-bit immediate operand.
+enum ImmediateOperandSize {
+ IOS_MASK = 0x0000F000,
+ IOS_DEFAULT = 0x0,
+ IOS_64 = 0x00001000
+};
+
// Everything that's in an Opcode (see below) except the three
// alternative opcode structs for different prefixes.
struct SpecificOpcode {
@@ -154,8 +164,8 @@ struct SpecificOpcode {
InstructionType type_;
// Description of the type of the dest, src and aux operands,
// put together from an enOperandType flag and an enAddressingMethod
// flag.
int flag_dest_;
int flag_source_;
int flag_aux_;
@@ -154,8 +164,8 @@ struct SpecificOpcode {
InstructionType type_;
// Description of the type of the dest, src and aux operands,
- // put together from an enOperandType flag and an enAddressingMethod
- // flag.
+ // put together from enOperandType, enAddressingMethod and
+ // enImmediateOperandSize flags.
int flag_dest_;
int flag_source_;

Powered by Google App Engine
This is Rietveld 408576698